# History

## 0.2.0-beta1 (2026-03-26)

* Add Backfills resource with full CRUD support: create, get latest, list incomplete, and cancel backfills ([#16](../../pull/16))
* Add public documentation link and fix broken links ([#17](../../pull/17))
* Remove broken documentation link ([#13](../../pull/13))
* Security: bump `actions/download-artifact` from 7 to 8 ([#14](../../pull/14))
* Security: bump `actions/upload-artifact` from 6 to 7 ([#15](../../pull/15))

## 0.1.0 (2025-10-28)

* First release on PyPI.
